from resources.hdr_merge import merging
from resources.crfio import CRF_importer
import unittest
import pickle
import numpy
import cv2


def load_pickle(file_name):
    with open(file_name, 'rb') as f:
        return pickle.load(f)


class TestMerging(unittest.TestCase):

    def test_merging(self):
        # Load the expected inputs and outputs
        images_w_exposure = load_pickle('examplers/pickles/list_10.pkl')
        expected_output = load_pickle('examplers/pickles/merge.pkl')
        crf = load_pickle('examplers/pickles/crf.pkl')

        # Call the function with the expected inputs
        result = merging(images_w_exposure, crf)

        # Check the function output
        self.assertTrue(numpy.array_equal(result, expected_output))

if __name__ == '__main__':
    unittest.main()


import unittest
from tests.test_crfio import TestCRFExportImport
from tests.test_merging import TestMerging
from tests.test_tonemap import TestTonemap
from tests.test_sharpen import TestSharpen
from tests.test_processor import TestProcessor
from tests.test_crf_calc import TestCRFCalc

def custom_test_suite():
    suite = unittest.TestSuite()

    # Add tests in a specific order
    suite.addTest(unittest.makeSuite(TestCRFExportImport))
    suite.addTest(unittest.makeSuite(TestMerging))
    suite.addTest(unittest.makeSuite(TestTonemap))
    suite.addTest(unittest.makeSuite(TestSharpen))
    suite.addTest(unittest.makeSuite(TestProcessor))
    suite.addTest(unittest.makeSuite(TestCRFCalc))

    return suite

if __name__ == '__main__':
    runner = unittest.TextTestRunner()
    runner.run(custom_test_suite())


import unittest
import os
import numpy as np
from resources import crfio


class TestCRFExportImport(unittest.TestCase):
    def setUp(self):
        """Setup a dummy CRF and a file path."""
        self.crf = np.array([1, 2, 3, 4, 5])  # Dummy CRF.
        self.path = "../config/test.npy"  # Temporary path for the test.

    def test_export_import(self):
        """Test the exporter and importer functions."""
        crfio.CRF_exporter(self.crf, self.path)

        # Assert that the file was created.
        self.assertTrue(os.path.exists(self.path), "File not created by exporter")

        loaded_crf = crfio.CRF_importer(self.path)

        # Assert that the loaded CRF matches the original one.
        np.testing.assert_array_equal(loaded_crf, self.crf, "Loaded CRF doesn't match original CRF")

        print("Both the tests passed successfully.")

    def tearDown(self):
        """Cleanup the created file after tests."""
        if os.path.exists(self.path):
            os.remove(self.path)


if __name__ == "__main__":
    unittest.main()


from resources.crfio import CRF_importer
from resources.hdr_merge import merging
from resources.ldr_sharpen import LDR_sharpen
from resources.tonemaping import tonemaping
from processor import processor
import numpy.testing as npt

import pickle
import unittest
import pickle
import numpy
import cv2


def load_pickle(file_name):
    with open(file_name, 'rb') as f:
        return pickle.load(f)

class TestProcessor(unittest.TestCase):
    def test_processor_b(self):
        input = load_pickle('./examplers/pickles/list_10.pkl')
        expected_output = load_pickle('./examplers/pickles/sharpen.pkl')
        # Call the function with the expected inputs
        result = processor(input, selector="B", gamma=1.4, saturation=2.0, sharpening_iteration=3, s=20, r=0.1)

        # Check the function output
        self.assertTrue(numpy.array_equal(result, expected_output))


    def test_processor_b_v2(self):
        input = load_pickle('./examplers/pickles/dict_10.pkl')
        expected_output = load_pickle('./examplers/pickles/sharpen.pkl')
        # Call the function with the expected inputs
        result = processor(input, selector="B", gamma=1.4, saturation=2.0, sharpening_iteration=3, s=20, r=0.1)

        try:
            npt.assert_array_equal(result, expected_output)
        except AssertionError as e:
            print(f'Test_processor_b failed with difference: {e}')
            raise

    def test_processor_b_crf(self):
        input = load_pickle('./examplers/pickles/list_100.pkl')
        expected_output = load_pickle('./examplers/pickles/crf.pkl')
        # Call the function with the expected inputs
        result = processor(input, selector="B", gamma=1.4, saturation=2.0, sharpening_iteration=3, s=20, r=0.1, mode="calibration")

        # Check the function output
        self.assertTrue(numpy.array_equal(result, expected_output))

    def test_processor_b_v2_crf(self):
        input = load_pickle('./examplers/pickles/list_100.pkl')
        expected_output = load_pickle('./examplers/pickles/crf.pkl')
        # Call the function with the expected inputs
        result = processor(input, selector="B", gamma=1.4, saturation=2.0, sharpening_iteration=3, s=20, r=0.1, mode="calibration")

        try:
            npt.assert_array_equal(result, expected_output)
        except AssertionError as e:
            print(f'Test_processor_b failed with difference: {e}')
            raise

if __name__ == '__main__':
    unittest.main()


from resources import tonemaping
import unittest
import pickle
import numpy
import cv2



def load_pickle(file_name):
    with open(file_name, 'rb') as f:
        return pickle.load(f)

class TestTonemap(unittest.TestCase):
    def test_tonemap(self):
        tonemap = load_pickle("examplers/pickles/merge.pkl")
        expected_output = load_pickle("examplers/pickles/tonemap.pkl")

        result = tonemaping.tonemaping(tonemap)

        # Check the function output
        self.assertTrue(numpy.array_equal(result, expected_output))
if __name__ == '__main__':
    unittest.main()


# setup.py

from setuptools import setup, find_packages

setup(
    name='global_tonemapping',
    version='0.1.201',
    url='https://github.com/Elessar11777',
    author='Elessar11777',
    author_email='Elessar11777@gmail.com',
    description='Petri Global Tonemapping Package',
    packages=find_packages(),
    install_requires=[
        "numpy>=1.21.0",
        "opencv-python>=4.5.3"
    ],
)



from resources.hdr_merge import merging
from resources.crf_calc import CRF_calculate
import unittest
import pickle
import numpy
import cv2

def load_pickle(file_name):
    with open(file_name, 'rb') as f:
        return pickle.load(f)

class TestCRFCalc(unittest.TestCase):
    def setUp(self):
        self.input = './examplers/pickles/list_100.pkl'
        self.output = './examplers/pickles/crf.pkl'

    def test_crf_calc(self):
        images_w_exposure = load_pickle(self.input)
        expected_output = load_pickle(self.output)

        result = CRF_calculate(images_w_exposure)

        # Check the function output
        self.assertTrue(numpy.array_equal(result, expected_output))


if __name__ == '__main__':
    unittest.main()


from resources import ldr_sharpen
import unittest
import pickle
import numpy
import cv2


def load_pickle(file_name):
    with open(file_name, 'rb') as f:
        return pickle.load(f)

class TestSharpen(unittest.TestCase):

    def test_sharpen_b(self):
        tonemap = load_pickle('examplers/pickles/tonemap.pkl')
        expected_output = load_pickle('examplers/pickles/sharpen.pkl')
        # Call the function with the expected inputs
        result = ldr_sharpen.LDR_sharpen(tonemap)

        # Check the function output
        self.assertTrue(numpy.array_equal(result, expected_output))

if __name__ == '__main__':
    unittest.main()